@@ -26,32 +26,38 @@ class CreateResourceAccountRequest(RpcRequest):
 		RpcRequest.__init__(self, 'ResourceManager', '2020-03-31', 'CreateResourceAccount')
 		self.set_protocol_type('https')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_AccountNamePrefix(self):
+	def get_AccountNamePrefix(self): # String
 		return self.get_query_params().get('AccountNamePrefix')
 
-	def set_AccountNamePrefix(self,AccountNamePrefix):
-		self.add_query_param('AccountNamePrefix',AccountNamePrefix)
-
-	def get_ParentFolderId(self):
+	def set_AccountNamePrefix(self, AccountNamePrefix):  # String
+		self.add_query_param('AccountNamePrefix', AccountNamePrefix)
+	def get_ParentFolderId(self): # String
 		return self.get_query_params().get('ParentFolderId')
 
-	def set_ParentFolderId(self,ParentFolderId):
-		self.add_query_param('ParentFolderId',ParentFolderId)
-
-	def get_DisplayName(self):
+	def set_ParentFolderId(self, ParentFolderId):  # String
+		self.add_query_param('ParentFolderId', ParentFolderId)
+	def get_DisplayName(self): # String
 		return self.get_query_params().get('DisplayName')
 
-	def set_DisplayName(self,DisplayName):
-		self.add_query_param('DisplayName',DisplayName)
+	def set_DisplayName(self, DisplayName):  # String
+		self.add_query_param('DisplayName', DisplayName)
+	def get_Tag(self): # Array
+		return self.get_query_params().get('Tag')
 
-	def get_PayerAccountId(self):
+	def set_Tag(self, Tag):  # Array
+		for index1, value1 in enumerate(Tag):
+			if value1.get('Value') is not None:
+				self.add_query_param('Tag.' + str(index1 + 1) + '.Value', value1.get('Value'))
+			if value1.get('Key') is not None:
+				self.add_query_param('Tag.' + str(index1 + 1) + '.Key', value1.get('Key'))
+	def get_PayerAccountId(self): # String
 		return self.get_query_params().get('PayerAccountId')
 
-	def set_PayerAccountId(self,PayerAccountId):
-		self.add_query_param('PayerAccountId',PayerAccountId)
\ No newline at end of file
+	def set_PayerAccountId(self, PayerAccountId):  # String
+		self.add_query_param('PayerAccountId', PayerAccountId)
